package com.utopiaindustries.qualitycontrol.activities;

import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.net.Uri;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import androidx.activity.EdgeToEdge;
import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentManager;
import androidx.fragment.app.FragmentTransaction;

import com.utopiaindustries.qualitycontrol.R;
import com.utopiaindustries.qualitycontrol.fragments.CheckingFragment;
import com.utopiaindustries.qualitycontrol.fragments.CuttingFragment;
import com.utopiaindustries.qualitycontrol.fragments.HomeFragment;
import com.utopiaindustries.qualitycontrol.fragments.PackingFragment;
import com.utopiaindustries.qualitycontrol.fragments.StitchingFragment;
import com.utopiaindustries.qualitycontrol.fragments.SubStoreFragment;
import com.utopiaindustries.qualitycontrol.helper.Helper;
import com.utopiaindustries.qualitycontrol.helper.Preference;

import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;

public class HomeActivity extends AppCompatActivity {

    private int currentFragmentIndex = 0;
    private final List<Fragment> fragmentList = new ArrayList<>();
    //Button btnNext;
    ImageView imgLogout;
    ImageView img_back;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_home);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;
        });

        if( !Helper.isNetworkConnected(this) ){
            Toast.makeText( this, "No Internet Connection", Toast.LENGTH_LONG ).show();
        }

        img_back = findViewById(R.id.img_back);
        imgLogout = findViewById(R.id.img_logout);

        imgLogout.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                alertLogOut(HomeActivity.this);
            }
        });

        img_back.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (getSupportFragmentManager().getBackStackEntryCount() > 0) {
                    getSupportFragmentManager().popBackStack(); // Go back to the previous fragment
                } else {
                    finish();
                }
            }
        });


        // Load the first fragment only if there's no saved instance
        if (savedInstanceState == null) {
            navigateToFragment(new HomeFragment(), false);
        }

    }

    public void navigateToFragment(Fragment fragment, boolean addToBackStack) {
        FragmentManager fragmentManager = getSupportFragmentManager();
        FragmentTransaction transaction = fragmentManager.beginTransaction()
                .replace(R.id.fragment_container, fragment);

        if (addToBackStack) {
            transaction.addToBackStack(null); // Add to the back stack
        }

        transaction.commit();
    }

    public void alertLogOut(Context con) {
        ViewGroup viewGroup = findViewById(android.R.id.content);

        TextView dialogOkBtn, dialogCancelBtn;

        AlertDialog.Builder builder = new AlertDialog.Builder(con);
        View view1 = LayoutInflater.from(con).inflate(R.layout.custom_layout_for_logout, viewGroup, false);
        builder.setCancelable(false);
        builder.setView(view1);

        dialogOkBtn = view1.findViewById(R.id.dialogOkBtn);
        dialogCancelBtn = view1.findViewById(R.id.dialogCancelBtn);

        AlertDialog alertDialog = builder.create();
        alertDialog.getWindow().setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));

        dialogOkBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {

                alertDialog.dismiss();

                Preference.setMyBooleanPref(Helper.project_file, "isLoggedIn", getApplicationContext(), false);
                Preference.setMyStringPref(Helper.project_file, Helper.firstTimeApiCall, getApplicationContext(), "false");

                Preference.remove(Helper.project_file, Helper.departmentId, getApplicationContext());
                Preference.remove(Helper.project_file, Helper.departmentName, getApplicationContext());

                Preference.remove(Helper.project_file, Helper.locationSiteId, getApplicationContext());
                Preference.remove(Helper.project_file, Helper.locationSiteName, getApplicationContext());

                Preference.remove(Helper.project_file, Helper.unitId, getApplicationContext());
                Preference.remove(Helper.project_file, Helper.unitName, getApplicationContext());

                Preference.remove(Helper.project_file, Helper.floorId, getApplicationContext());
                Preference.remove(Helper.project_file, Helper.floorName, getApplicationContext());

                Helper.RemoveArrayList(Helper.listCutting,getApplicationContext());
                Helper.RemoveArrayList(Helper.listStitching,getApplicationContext());
                Helper.RemoveArrayList(Helper.listChecking,getApplicationContext());
                Helper.RemoveArrayList(Helper.listPacking,getApplicationContext());
                Helper.RemoveArrayList(Helper.listSubStore,getApplicationContext());

                finish();
                Intent i = new Intent(HomeActivity.this, LoginActivity.class);
                i.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP | Intent.FLAG_ACTIVITY_NEW_TASK);
                startActivity(i);
                overridePendingTransition(R.anim.slide_in_right, R.anim.slide_out_left);

            }
        });

        dialogCancelBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {

                alertDialog.dismiss();
                //Toast.makeText(con, "Cancel", Toast.LENGTH_SHORT).show();

            }
        });

        alertDialog.show();
    }

    // Method to navigate to a specific fragment
    /*public void navigateToFragment(Fragment fragment, boolean addToBackStack) {
        androidx.fragment.app.FragmentTransaction transaction = getSupportFragmentManager()
                .beginTransaction()
                .replace(R.id.fragment_container, fragment);

        if (addToBackStack) {
            transaction.addToBackStack(null);
        }

        transaction.commit();
    }*/

    /*private void navigateNext() {
        if (currentFragmentIndex < fragmentList.size() - 1) {
            currentFragmentIndex++;
            loadFragment(fragmentList.get(currentFragmentIndex));

            // Change button text to "Finish" on the last fragment
            if (currentFragmentIndex == fragmentList.size() - 1) {
                Button btnNext = findViewById(R.id.btn_next);
                btnNext.setText("Finish");
            }
        } else {
            // Navigate to Summary Activity
            Intent intent = new Intent(this, SummaryActivity.class);
            startActivity(intent);
            finish();
        }
    }*/

    private void loadFragment(Fragment fragment) {
        getSupportFragmentManager().beginTransaction()
                .replace(R.id.fragment_container, fragment)
                .addToBackStack(null)
                .commit();
    }

    /*@Override
    public void onBackPressed() {
        *//*Fragment myFragment = getSupportFragmentManager().findFragmentById(R.id.fragment_container);
        if (myFragment instanceof CuttingFragment) {
            finish();
        } else {
            if (getSupportFragmentManager().getBackStackEntryCount() > 0) {
                getSupportFragmentManager().popBackStack();
            } else {
                super.onBackPressed();
            }
        }*//*
        if (getSupportFragmentManager().getBackStackEntryCount() > 0) {
            Log.i("TAG", "=============onBackPressed - Popping backstack====");
            getSupportFragmentManager().popBackStack();
        } else {
            Log.i("TAG", "=============onBackPressed called because nothing on backstack====");
            super.onBackPressed();
        }
    }*/

    @Override
    public void onBackPressed() {
        if (getSupportFragmentManager().getBackStackEntryCount() > 0) {
            getSupportFragmentManager().popBackStack(); // Go back to the previous fragment
        } else {
            super.onBackPressed(); // Exit the activity
        }
    }

}