package com.utopiaindustries.qualitycontrol.adapters;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.EditText;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.utopiaindustries.qualitycontrol.models.Department;

import java.util.List;

public class DepartmentItemAdapter extends RecyclerView.Adapter<DepartmentItemAdapter.ItemViewHolder> {

    private final List<Department> items;
    private OnItemClickListener onItemClickListener;
    private EditText editText;
    private RecyclerView recyclerView;

    public DepartmentItemAdapter(List<Department> items, OnItemClickListener listener, EditText editText, RecyclerView recyclerView) {
        this.items = items;
        this.onItemClickListener = listener;
        this.editText = editText;
        this.recyclerView = recyclerView;
    }

    public interface OnItemClickListener {
        void onItemClick(Department item);
    }

    @NonNull
    @Override
    public ItemViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext())
                .inflate(android.R.layout.simple_list_item_1, parent, false);
        return new ItemViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull ItemViewHolder holder, int position) {
        Department item = items.get(position);
        holder.textView.setText(item.getTitle());

        // Set the click listener on the item view
        holder.itemView.setOnClickListener(v -> {
            editText.setText(item.getTitle());
            recyclerView.setVisibility(View.GONE);

            if (onItemClickListener != null) {
                onItemClickListener.onItemClick(item);
            }
        });
        /*holder.itemView.setOnClickListener(v -> {
            // Handle item selection
            System.out.println("Selected: " + item);
        });*/
    }

    @Override
    public int getItemCount() {
        return items.size();
    }

    static class ItemViewHolder extends RecyclerView.ViewHolder {
        TextView textView;

        public ItemViewHolder(@NonNull View itemView) {
            super(itemView);
            textView = itemView.findViewById(android.R.id.text1);
        }
    }
}
